@@ -28,7 +28,7 @@
 #include <glib/gi18n.h>
 #include <glib/gprintf.h>
 #include "xfce-taskmanager-linux.h"
-#include <sys/sysinfo.h>
+/* #include <sys/sysinfo.h> */
 
 void get_task_details(pid_t pid,struct task *task)
 {
@@ -169,7 +169,10 @@ void get_task_details(pid_t pid,struct task *task)
 		task->time_percentage = 0;
 		task->ppid = ppid;
 
-		fstat(fd,&st);
+		sprintf(line,"/proc/%d/task",(int)pid);
+		/* SF bug #843: /proc/%d/stat owned by UID instead of EUID */
+		if (stat(line,&st) < 0)
+			fstat(fd,&st);
 		task->uid=st.st_uid;
 		passwdp = getpwuid(task->uid);
 		if( passwdp != NULL && passwdp->pw_name != NULL)
@@ -276,7 +279,8 @@ gboolean get_system_status (system_status *sys_stat)
 
     if(!cpu_count)
     {
-        cpu_count=get_nprocs();
+        /* cpu_count=get_nprocs(); */
+        cpu_count = sysconf(_SC_NPROCESSORS_ONLN);
     }
     sys_stat->cpu_count=cpu_count;
     return TRUE;
